@@ -411,6 +411,14 @@ install_console() {
 		additional_env+=" -e REGISTRY_SCANNERS=${REGISTRY_SCANNERS} "
 	fi
 
+	if [[ -n "${REGISTRY_SCAN_DEFENDER_CONCURRENCY}" ]]; then
+		additional_env+=" -e REGISTRY_SCAN_DEFENDER_CONCURRENCY=${REGISTRY_SCAN_DEFENDER_CONCURRENCY} "
+	fi
+
+	if [[ -n "${REGISTRY_CHANNEL_SIZE}" ]]; then
+		additional_env+=" -e REGISTRY_CHANNEL_SIZE=${REGISTRY_CHANNEL_SIZE} "
+	fi
+
 	if [[ -n "${BUILDAH_DETECTION_ENABLED}" ]]; then
 		additional_env+=" -e BUILDAH_DETECTION_ENABLED=${BUILDAH_DETECTION_ENABLED} "
 	fi
@@ -443,6 +451,22 @@ install_console() {
 		additional_env+=" -e CORE_PROJECTS_UPDATE_WORKERS=${CORE_PROJECTS_UPDATE_WORKERS} "
 	fi
 
+	if [[ -n "${CORE_SSL_CLIENT_CERT_HEADER_NAME}" ]]; then
+		additional_env+=" -e CORE_SSL_CLIENT_CERT_HEADER_NAME=${CORE_SSL_CLIENT_CERT_HEADER_NAME} "
+	fi
+
+	if [[ -n "${CORE_SSL_CLIENT_CERT_ENCODING}" ]]; then
+		additional_env+=" -e CORE_SSL_CLIENT_CERT_ENCODING=${CORE_SSL_CLIENT_CERT_ENCODING} "
+	fi
+
+	if [[ -n "${AGENTLESS_USE_CUSTOM_AMI}" ]]; then
+		additional_env+=" -e AGENTLESS_USE_CUSTOM_AMI=${AGENTLESS_USE_CUSTOM_AMI} "
+	fi
+
+	if [[ -n "${AGENTLESS_CUSTOM_AMI_PER_REGION}" ]]; then
+		additional_env+=" -e AGENTLESS_CUSTOM_AMI_PER_REGION=${AGENTLESS_CUSTOM_AMI_PER_REGION} "
+	fi
+
 	# All console containers resides on the same network
 	${docker} ${docker_action} \
 		$(get_userns_flag) \
